@@ -32,7 +32,7 @@ def str_2_json(s):
 def is_none_str(s):
     if isinstance(s, int):
         return False
-    if not s or len(str(s.strip())) < 1:
+    if not s or len(str(str(s).strip())) < 1:
         return True
     return False
 
